==> tellico_3.4.4.orig.tar.xz: tellico-3.4.4/src/charts/yeardistributionreport.h <==
/***************************************************************************
    Copyright (C) 2021 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_YEARDISTRIBUTIONREPORT_H
#define TELLICO_YEARDISTRIBUTIONREPORT_H

#include "chartreport.h"

namespace Tellico {

class YearDistributionReport : public ChartReport {

public:
  YearDistributionReport();

  virtual QString title() const Q_DECL_OVERRIDE;
  virtual QWidget* createWidget()  Q_DECL_OVERRIDE;

private:
  class View;
};

} // end namespace
#endif

==> tellico-4.1.4.tar.xz: tellico-4.1.4/src/charts/yeardistributionreport.h <==
/***************************************************************************
    Copyright (C) 2021 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_YEARDISTRIBUTIONREPORT_H
#define TELLICO_YEARDISTRIBUTIONREPORT_H

#include "chartreport.h"

namespace Tellico {

class YearDistributionReport : public ChartReport {

public:
  YearDistributionReport();

  virtual QString title() const override;
  virtual QWidget* createWidget() override;

private:
  class View;
};

} // end namespace
#endif
